% process the biwi files
% to create a matfile containing 
% - a list of images 
% - pose labels
% - bounding boxes
% tested with matlab 2019a on ubuntu 18

% load from mainfile
global biwi_folder;
biwi_dir = biwi_folder;
global data_folder

%% Loop through all the foldersIDs
folder_results = cell(24,2);
num_poses = 0;
for fID=1:24
  folder = num2str(fID,'%02d');
  folder = fullfile(biwi_dir,folder);
  fprintf('Processing folder: %s\n', folder)
 
  %% load the calibration file from the rgb calib
  [intrinsic,exrot,trans]=read_biwi_cal_file(folder);
  
  %% load ground truth pose data
  [R, var_trans, images] = read_biwi_pose_data(folder);
  num_images = length(images);
  fprintf('Processing %s images\n', num2str(num_images))
  % skipping the translations...
  if num_images ~= length(R)
   error('error');
  end
  %% fix angles
  var_pose = zeros(num_images,3);
  for j=1:num_images   
     new_r = exrot * R{j};
     new_ang = rad2deg(r_to_eul(new_r));
     % set as roll yaw pitch;
     var_pose(j,:) = new_ang .* [1 -1 -1]; 
  end
  
  folder_results{fID,1} = var_pose;
  folder_results{fID,2} = images;
  
  num_poses = num_poses + size(var_pose,1);
end

%% read the bounding box data
data = load(fullfile('mats','biwi_bboxes.mat'));
bboxes = data.refined_bboxes;
image_names = data.images;
%% merge all to the biwi+ database
poses = zeros(num_poses,3);
images = cell(0);

idx = 1;
for i=1:24
  num_poses_folder = size(folder_results{i,1},1);
  poses(idx:idx+num_poses_folder-1,:) = folder_results{i,1};
  idx = idx+num_poses_folder;
  images = [images ; folder_results{i,2}];
end
%% check that the bboxes have the same image names
% if this does not work, you might need to sort the files in 
% read_biwi_pose_data
for i=1:length(image_names)
  name_new = images{i}(end-21:end);
  name_check = image_names{i};
  %% os independent
  match = ['/','\'];
  name_new   = erase(name_new,match);
  name_check = erase(name_check,match);
  if(strcmp(name_new,name_check) == 1)
    %disp(name_new);
    %disp(name_check);
  else
    disp(name_new);
    disp(name_check);
    error('wrong assignment');
  end
end

%% save as -v7 so we can open it with scipy
save(fullfile(data_folder,'Biwi_plus.mat'),'poses','bboxes','images','-v7');


